@@ -3,14 +3,30 @@ package MooX::LazierAttributes;
 use strict;
 use warnings;
 use Scalar::Util qw/reftype blessed/;
-
 use MooX::ReturnModifiers qw/return_modifiers/;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
+
+use constant ro => 'ro';
+use constant rw => 'rw';
+use constant lzy => ( lazy => 1 );
+use constant bld => ( builder => 1 );
+use constant lzy_bld => ( lazy_build => 1 );
+use constant trg => ( trigger => 1 );
+use constant clr => ( clearer => 1 );
+use constant req => ( required => 1 );
+
+our @EXPORT = qw/$ro $rw/;
 
 sub import {
     my $target = caller;
     my %modifiers = return_modifiers($target);
+        
+    {
+        no strict 'refs';
+        ${"${target}::"}{$_} = ${__PACKAGE__."::"}{$_} 
+        foreach ( qw/ro rw lzy bld lzy_bld trg clr req/ );
+    }
 
     my $attributes = sub {
         my %attr = @_;
@@ -66,7 +82,7 @@ MooX::LazierAttributes - Lazier Attributes.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
@@ -78,9 +94,9 @@ Version 0.04
     use MooX::LazierAttributes;
 
     attributes (
-        one   => ['ro'],
-        two   => ['ro', {}],
-        three => ['rw', $obj { clearer => 1 }]
+        one   => [ro],
+        two   => [ro, {}],
+        three => [rw, My::Thing->new(), { lzy, clr }]
     );
 
     .....
@@ -98,6 +114,42 @@ Version 0.04
 
 =head2 attributes
 
+=head1 Constants
+
+=head3 ro
+
+'ro'
+
+=head3 rw
+
+'rw'
+
+=head3 lzy;
+
+( lazy => 1 )
+
+=head3 bld
+
+( builder => 1 )
+
+=head2 lzy_bld 
+
+( lazy_build => 1 ),
+
+=head2 trg
+
+( tigger => 1 ),
+
+=head2 req
+
+( required => 1 ),
+
+=head1 Maybe in the future
+
+lzy_bld_hash
+
+( lazy => 1, builder => 1 ) .... sub _build_thing { return { } }
+
 =head1 AUTHOR
 
 Robert Acock, C<< <thisusedtobeanemail at gmail.com> >>
